summaryrefslogtreecommitdiff
path: root/nuttx/configs/lm3s8962-ek/src
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-03-08 15:50:26 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-03-08 15:50:26 -0600
commitfc300bda7bf9d68ac5d75fa7b732692eeeae5221 (patch)
tree295b1a1ffbbfea2990cdee1d05a05ca2577c42c0 /nuttx/configs/lm3s8962-ek/src
parent3100722cdd78ff94412a760138e2fd4fdc319548 (diff)
downloadpx4-nuttx-fc300bda7bf9d68ac5d75fa7b732692eeeae5221.tar.gz
px4-nuttx-fc300bda7bf9d68ac5d75fa7b732692eeeae5221.tar.bz2
px4-nuttx-fc300bda7bf9d68ac5d75fa7b732692eeeae5221.zip
functions and definitions renamed from lm_ to tiva_
Diffstat (limited to 'nuttx/configs/lm3s8962-ek/src')
-rw-r--r--nuttx/configs/lm3s8962-ek/src/lm3s8962ek_internal.h4
-rw-r--r--nuttx/configs/lm3s8962-ek/src/up_ethernet.c8
2 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/configs/lm3s8962-ek/src/lm3s8962ek_internal.h b/nuttx/configs/lm3s8962-ek/src/lm3s8962ek_internal.h
index ece21e18c..675179458 100644
--- a/nuttx/configs/lm3s8962-ek/src/lm3s8962ek_internal.h
+++ b/nuttx/configs/lm3s8962-ek/src/lm3s8962ek_internal.h
@@ -56,12 +56,12 @@
* expanded).
*/
-#if LM_NSSI == 0
+#if TIVA_NSSI == 0
# undef CONFIG_SSI0_DISABLE
# define CONFIG_SSI0_DISABLE 1
# undef CONFIG_SSI1_DISABLE
# define CONFIG_SSI1_DISABLE 1
-#elif LM_NSSI == 1
+#elif TIVA_NSSI == 1
# undef CONFIG_SSI1_DISABLE
# define CONFIG_SSI1_DISABLE 1
#endif
diff --git a/nuttx/configs/lm3s8962-ek/src/up_ethernet.c b/nuttx/configs/lm3s8962-ek/src/up_ethernet.c
index 487e4004a..bc20ea0f1 100644
--- a/nuttx/configs/lm3s8962-ek/src/up_ethernet.c
+++ b/nuttx/configs/lm3s8962-ek/src/up_ethernet.c
@@ -67,12 +67,12 @@
*
* Description:
* For the Ethernet Eval Kits, the MAC address will be stored in the non-volatile
* USER0 and USER1 registers. If CONFIG_LM_BOARDMAC is defined, this function
* will obtain the MAC address from these registers.
*
************************************************************************************/
-#ifdef CONFIG_LM_BOARDMAC
+#ifdef CONFIG_TIVA_BOARDMAC
void tiva_ethernetmac(struct ether_addr *ethaddr)
{
uint32_t user0;
@@ -80,8 +80,8 @@ void tiva_ethernetmac(struct ether_addr *ethaddr)
/* Get the current value of the user registers */
- user0 = getreg32(LM_FLASH_USERREG0);
- user1 = getreg32(LM_FLASH_USERREG1);
+ user0 = getreg32(TIVA_FLASH_USERREG0);
+ user1 = getreg32(TIVA_FLASH_USERREG1);
nlldbg("user: %06x:%06x\n", user1 & 0x00ffffff, user0 & 0x00ffffff);
DEBUGASSERT(user0 != 0xffffffff && user1 != 0xffffffff);
@@ -67,12 +67,12 @@
* Description:
* For the Ethernet Eval Kits, the MAC address will be stored in the non-volatile
- * USER0 and USER1 registers. If CONFIG_LM_BOARDMAC is defined, this function
+ * USER0 and USER1 registers. If CONFIG_TIVA_BOARDMAC is defined, this function
* will obtain the MAC address from these registers.
*